This is a python utility that uploads ipa/apk binary to s3 storage using API gateway.

After installation just run in terminal:

**waste-uploader**

and it shows you variables that you need to define.

Otherwise, there is a list:

- AWS_ACCESS_KEY_ID
- AWS_SECRET_ACCESS_KEY
- PROJECT
- STAGE
- PLATFORM (ios/android)
- VERSION
- BUILD_NUM
- RELEASE_NOTES
- FILE_PATH
- BUNDLE_ID
